.. _api:

API Reference
=============

In this section you will find a detailed specification of all the public functions and classes in Orion.

.. toctree::
   :maxdepth: 2

   orion
   evaluation
   prim
